/**
 * @public
 */
export declare interface AuthenticatePayload {
    /**
     * A JWT token for the active user.
     */
    token: string;
}

/**
 * @public
 */
export declare interface GetBaseURLPayload {
    /**
     * BaseURL of the Swagger API.
     */
    baseURL: string;
}

/**
 * @public
 */
export declare interface GetConfigPayload {
    /**
     * Arbitrary user configuration.
     */
    config: any;
}

/**
 * @public
 */
export declare interface GetSelectedItemPayload {
    /**
     * ID of the currently selected Tracker Item, if applies. `undefined` otherwise.
     */
    itemId: string | undefined;
}

/**
 * @public
 *
 * An object which behaves like a child-window in a browser context.
 */
export declare type MessageBroker = Pick<Window, 'addEventListener'> & {
    parent: Pick<Window, 'postMessage'>;
};

/**
 * @public
 */
export declare interface ReloadItemPayload {
    /**
     * Tracker Item ID to reload.
     */
    itemId: string;
}

/**
 * An API abstraction which provides an interface for a frontend application running inside an IFrame inside codeBeamer,
 * to communicate with the codeBeamer UI via the browser's `postMessage` API.
 *
 * @public
 */
export declare class WidgetApi {
    private readonly client;
    /**
     * Initializes an API instance.
     *
     * @param window - A window-like instance which provides the `postMessage` interface. Usually just simply `window`.
     * @param widgetId - A unique string to represent this widget API instance.
     * @param origin - The origin of codeBeamer. Can be `"*"` if the host is unknown.
     */
    constructor(window: MessageBroker, widgetId: string, origin: string);
    /**
     * Request a JWT token for the currently logged-in user. The token may expire.
     */
    authenticate(): Promise<AuthenticatePayload>;
    /**
     * Asks codeBeamer to resize the IFrame window vertically inside the UI. Only works on the Tracker Item Details page.
     *
     * @param height - Preferred height in browser pixels.
     */
    resize(height: number): Promise<void>;
    /**
     * Queries which tracker item is selected on the codeBeamer UI. May only work on certain pages.
     * It may return `undefined` if there is no tracker item selected.
     */
    getSelectedItem(): Promise<GetSelectedItemPayload>;
    /**
     * Requests the user provided configuration for this particular widget instance.
     */
    getConfig(): Promise<GetConfigPayload>;
    /**
     * Asks codeBeamer to reload a Tracker Item if it's present on the UI. May only work on certain pages.
     */
    reloadItem(config: ReloadItemPayload): Promise<void>;
    /**
     * Requests the Swagger API's base URL, including the proper context. Ex.: https://codebeamer.com/cb/api
     */
    getBaseURL(): Promise<GetBaseURLPayload>;
    /**
     * Registers a callback to be called whenever the user selects a tracker item on the codeBeamer UI. May only work on
     * certain pages.
     *
     * @param callback - A function to be called when the selection changes.
     */
    onSelectedItemChange(callback: (item: string) => void): () => void;
}

export { }
